<?php

require_once __DIR__ ."/../../../Classes/Wp_caller.php";
require_once __DIR__ ."/../../../Kernel/API/Entity/APIResponseEntity.php";
require_once __DIR__ ."/../../../Kernel/API/Entity/Entity.php";
require_once __DIR__ ."/../../../Kernel/API/Manager/DigitalSignageException.php";
require_once __DIR__ ."/../../../Kernel/Translations/DigitalSignageTranslate.php";

class API_Linker
{
    public const API_URL = "https://api.digitalsignage4.com/API_v2/";

    /**
     * @param $remoteEntityName
     * @param string | Entity $entityName
     * @throws DigitalSignageException
     */
    public static function get_entitys($remoteEntityName, $entityName, $bearerToken = "")
    {
        if (class_exists($entityName)) {
            $responseApi = self::get($remoteEntityName, $bearerToken);

            $entitys = $responseApi->getDatas();

            foreach ($entitys as $key => $entity) {
                $tempEntity = new $entityName();

                $entitys[$key] = $tempEntity->hydrate($entity);
            }

            return $entitys;
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('class_introuvable', $entityName));
        }
    }

    /**
     * @param $remoteEntityName
     * @param string $bearerToken
     * @return APIResponseEntity
     * @throws DigitalSignageException
     */
    public static function get($remoteEntityName, $bearerToken = "")
    {
        if (!self::isCurlInstalled()) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('api_non_joingnable_curl_error', 'curl', '0', 'Curl not installed or disabled.'));
        }

        // create curl resource
        $curl_handler = curl_init();

        // set url
        $url = self::API_URL . $remoteEntityName;
        curl_setopt($curl_handler, CURLOPT_URL, $url);

        //return the transfer as a string
        curl_setopt($curl_handler, CURLOPT_RETURNTRANSFER, 1);

        //parametres generaux du curl
        curl_setopt($curl_handler, CURLOPT_VERBOSE, false);
        curl_setopt($curl_handler, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl_handler, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible;)");
        curl_setopt($curl_handler, CURLOPT_CONNECTTIMEOUT, 0);

        curl_setopt($curl_handler, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl_handler, CURLOPT_SSL_VERIFYHOST, 0);

        curl_setopt($curl_handler, CURLOPT_TIMEOUT, 60); //timeout in seconds
        curl_setopt($curl_handler, CURLOPT_HEADER, 0);

        // Ajout du bearer token
        if (!empty($bearerToken)) {
            curl_setopt($curl_handler, CURLOPT_HTTPHEADER, array(
                "Content-Type: multipart/form-data",
                "Authorization: Bearer " . $bearerToken,
            ));
        }

        // Validité du retour de l'api
        $responseValid = false;

        // Boucle d'appel de l'api, 10 fois maxi
        for ($i = 0; $i < 10; $i++) {
            // Execution de la requete curl
            $output = curl_exec($curl_handler);


            if ($output != false && self::isJson($output) && count(json_decode($output, true)) == 5) { // les responses de l'api sont composées de 5 elements
                $responseValid = true;
                break;
            }
        }

        if ($output == false) {
            //Curl n'arrive pas a joindre l'api apres 10 tentatives
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('api_non_joingnable_curl_error', 'curl', curl_errno($curl_handler), curl_error($curl_handler)));
        }

        // Fermeture du curl
        curl_close($curl_handler);

        //check si la reponse est bien du type json est pas une erreur 404 ou une page html simple
        try {
            if ($responseValid) {
                $output = json_decode($output, true);
                $tempEntity = new APIResponseEntity();
                $responseHydrated = $tempEntity->hydrate($output);
                return $responseHydrated;
            } else {
                throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('api_non_joingnable'));
            }
        } catch (Exception $e) {
            throw new DigitalSignageException($e->getMessage());
        }
    }


    /**
     * @throws DigitalSignageException
     */
    public static function post($remoteEntityName, $data, $bearerToken = "")
    {
        if (!self::isCurlInstalled()) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('api_non_joingnable_curl_error', 'curl', '0', 'Curl not installed or disabled.'));
        }

        // create curl resource
        $curl_handler = curl_init();

        // set url
        $url = self::API_URL . $remoteEntityName;
        curl_setopt($curl_handler, CURLOPT_URL, $url);

        //return the transfer as a string
        curl_setopt($curl_handler, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($curl_handler, CURLOPT_POST, 1);

        curl_setopt($curl_handler, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl_handler, CURLOPT_SSL_VERIFYHOST, 0);


        //parametres generaux du curl
        curl_setopt($curl_handler, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl_handler, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible;)");
        curl_setopt($curl_handler, CURLOPT_CONNECTTIMEOUT, 0);
        curl_setopt($curl_handler, CURLOPT_TIMEOUT, 60); //timeout in seconds
        curl_setopt($curl_handler, CURLOPT_HEADER, 0);

        // Parametres de la requête
        curl_setopt($curl_handler, CURLOPT_POSTFIELDS, $data);


        curl_setopt($curl_handler, CURLOPT_HTTPHEADER, array(
            "Content-Type: multipart/form-data"
        ));

        // Ajout du bearer token
        if (!empty($bearerToken)) {
            curl_setopt($curl_handler, CURLOPT_HTTPHEADER, array(
                "Content-Type: multipart/form-data",
                "Authorization: Bearer " . $bearerToken,
            ));
        }

        // Validité du retour de l'api
        $responseValid = false;

        // Boucle d'appel de l'api, 10 fois maxi
        for ($i = 0; $i < 10; $i++) {
            // Execution de la requete curl
            $output = curl_exec($curl_handler);

            if ($output != false  && self::isJson($output) && count(json_decode($output, true)) == 5) { // les responses de l'api sont composées de 5 elements
                $responseValid = true;
                break;
            }
        }

        if ($output == false) {
            //Curl n'arrive pas a joindre l'api apres 10 tentatives
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('api_non_joingnable_curl_error', 'curl', curl_errno($curl_handler), curl_error($curl_handler)));
        }

        // Fermeture du curl
        curl_close($curl_handler);

        //check si la reponse est bien du type json est pas une erreur 404 ou une page html simple
        if ($responseValid) {
            $output = json_decode($output, true);
            $tempEntity = new APIResponseEntity();
            return $tempEntity->hydrate($output);
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('api_non_joingnable'));
        }
    }

    private static function isJson($string)
    {
        json_decode($string);
        return (json_last_error() == JSON_ERROR_NONE);
    }


    private static function isCurlInstalled()
    {
        return function_exists('curl_version');
    }
}
