<?php

namespace Controllers;

use Classes\Tools;
use Classes\Tools_DS4;
use Kernel\Translations\Translate;
use Classes\Wp_caller;
use Google\Exception;
use Kernel\API\Entity\AutomatisationEntity;
use Kernel\API\Entity\PlaylistEntity;
use Kernel\API\Manager\AutomatisationManager;
use Kernel\API\Manager\DigitalSignageException;
use Kernel\API\Manager\GabaritManager;
use Kernel\API\Manager\PlaylistManager;

class CreationController extends Controller
{
    public function generatePage()
    {
        $this->handleAjaxRequest($_POST);

        $vue = (isset($_GET['automatisationVue'])) ? ($_GET['automatisationVue']) : 'liste';

        $autos = ( new AutomatisationManager(new Wp_caller()) )->get_automatisations();

        foreach ($autos as $key => $auto) {
            $playlist = ( new PlaylistManager(new Wp_caller()) )->get_playlist($auto->getPlaylist());
            if ($playlist) {
                $autos[ $key ]->setPlaylist($playlist);
            } else {
                $autos[ $key ]->setPlaylist(null);
            }
        }

        if ($vue == "liste") {
            $this->assign(array(
                'pageProduits'    => Tools_DS4::getProductsUrl(),
                'automatisations' => $autos,
                "ManualUrl"  => Tools_DS4::getModuleUrl() . "Kernel/Views/img/DS4-Manual.png",
                "AutomateUrl"        => Tools_DS4::getModuleUrl() . "Kernel/Views/img/DS4-Automate.png",
                "BatchUrl" => Tools_DS4::getModuleUrl() . "Kernel/Views/img/DS4-Batch.png",
                'playlistBaseUrl' => Tools::getUrlRedirect('mes_playlists')
            ));
            $this->setWPTemplate("Creation_video/creation");
        } else {
            if (isset($_POST)) {
                if (isset($_POST['save_automatisation'])) {
                    ob_get_clean();
                    ob_start();

                    if (empty($_POST['when'])) {
                        $_POST['when'] = " ";
                    }

                    $update = true;

                    $id = $_POST['id'];
                    if (! $id) {
                        $id     = ( new AutomatisationManager(new Wp_caller()) )->get_last_id() + 1;
                        $update = false;
                    }

                    $automatisation = new AutomatisationEntity();
                    $automatisation->setActive(true)
                                   ->setId($id)
                                   ->setName(sanitize_text_field(stripslashes($_POST['name'])))
                                   ->setCategorie(($_POST['categories'] == '') ? array() : explode(',', $_POST['categories']))
                                   ->setCreated(0)
                                   ->setHookCreation((strpos($_POST['when'], 'creat') !== false))
                                   ->setHookSell((strpos($_POST['when'], 'sell') !== false))
                                   ->setPriceMax(sanitize_text_field($_POST['prixMax']))
                                   ->setPriceMin(sanitize_text_field($_POST['prixMin']))
                                   ->setGabarit($_POST['gabarit'])
                                   ->setPlaylist($_POST['playlist'])
                                   ->setNbProduit(sanitize_text_field($_POST['sellNbProduit']))
                                   ->setNbJours(sanitize_text_field($_POST['sellNbJours']));


                    try {
                        $automatisationInstance = new AutomatisationManager(new Wp_caller());

                        if ($update) {
                            if ($automatisationInstance->get_automatisation($id) == $automatisation) {
                                echo esc_html(Translate::getTraduction("Parametres_inchangé"));
                            } else {
                                if (( new AutomatisationManager(new Wp_caller()) )->update_automatisation($automatisation)) {
                                    echo esc_html("ok:" . $id);
                                } else {
                                    echo esc_html(Translate::getTraduction("MAJ_bdd_impossible"));
                                }
                            }
                        } else {
                            if (( new AutomatisationManager(new Wp_caller()) )->add_automatisation($automatisation)) {
                                echo esc_html("ok:" . $id);
                            } else {
                                echo esc_html(Translate::getTraduction("MAJ_bdd_impossible"));
                            }
                        }
                    } catch (DigitalSignageException $e) {
                        echo esc_html("erreur : " . $e->getMessage());
                    }

                    die(ob_get_clean());
                }
            }

            $this->assign(array(
                'playlists' => ( new PlaylistManager(new Wp_caller()) )->get_playlists(),
                'gabarits'  => GabaritManager::instance()->getGabarits(),
                'datas'     => $this->getDatas()
            ));

            $this->setWPTemplate("Creation_video/add_auto");
        }
    }

    private function categorieTree($selected_cat = array())
    {
        $categories = $this->getWooCommerceCategories();
        ob_start();
        echo ("<div class='caseCategorie'>");
        $this->categoriesGenerateTree($categories, $selected_cat, 0);
        echo ("</div>");

        return ob_get_clean();
    }

    private function getWooCommerceCategories()
    {
        $args = array(
            'taxonomy'     => 'product_cat',
            'orderby'      => 'name',
            'show_count'   => 0,
            'pad_counts'   => 0,
            'hierarchical' => 0,
            'title_li'     => '',
            'hide_empty'   => 0
        );

        return get_categories($args);
    }

    private function categoriesGenerateTree($categories, $selected_cat, $parentId)
    {
        foreach ($categories as $categorie) {
            if ($categorie->parent == $parentId) {
                $checked = (in_array($categorie->term_id, $selected_cat)) ? "checked" : "";
                echo ('<div style="margin-left: 20px"><label><input type="checkbox" name="cat[]" id="" ' . $checked . ' value="' . $categorie->term_id . '">' . $categorie->name . "</label><br>");
                $this->categoriesGenerateTree($categories, $selected_cat, $categorie->term_id);
                echo ('</div>');
            }
        }
    }

    private function handleAjaxRequest($post)
    {
        if (isset($post['request'])) {
            ob_get_clean();
            ob_start();

            try {
                switch ($post['request']) {

                    case 'changeActive':

                        $id      = $post['automatisationId'];
                        $active  = $post['active'];
                        $autoc   = new AutomatisationManager(new Wp_caller());
                        $automat = $autoc->get_automatisation($id);

                        if ($automat) {
                            $automat->setActive($active);

                            if ($autoc->update_automatisation($automat)) {
                                echo esc_html("ok");
                            } else {
                                echo esc_html("error");
                            }
                        } else {
                            echo esc_html(Translate::getTraduction("Erreur_automat_non_trouve"));
                        }

                        break;


                    case 'delete':

                        if (( new AutomatisationManager(new Wp_caller()) )->remove_automatisation(( new AutomatisationManager(new Wp_caller()) )->get_automatisation($post['id']))) {
                            echo esc_html("ok");
                        } else {
                            echo esc_html(Translate::getTraduction("Suppression_impossible"));
                        }

                        break;

                    case 'add_playlist':

                        $playlist_id   = null;
                        $playlist_name = null;

                        if (! empty($_POST['new_playlist_name'])) {
                            $playlist_controller = new PlaylistManager(( new Wp_caller() ));
                            $playlist_id         = $playlist_controller->get_last_id() + 1;
                            $playlist_name       = stripslashes($_POST['new_playlist_name']);

                            $playlist = new PlaylistEntity();
                            $playlist->set_videos(array())
                                     ->set_title($playlist_name)
                                     ->set_active(true)
                                     ->set_limit(0)
                                     ->set_id($playlist_id);

                            try {
                                if (! $playlist_controller->add_playlist($playlist)) {
                                    $playlist_id   = null;
                                    $playlist_name = null;
                                }
                            } catch (DigitalSignageException $e) {
                                $playlist_id   = null;
                                $playlist_name = null;
                            }
                        }

                        echo json_encode(array( $playlist_name, $playlist_id ));

                        break;

                }
            } catch (DigitalSignageException $e) {
                $e->echoError();
            }

            die(ob_get_clean());
        }
    }

    private function getDatas()
    {
        $defautData = array(
            'id'            => "",
            'name'          => "",
            'playlist'      => "",
            'populaire'     => false,
            'new'           => false,
            'priceMin'      => '',
            'priceMax'      => '',
            'categorieTree' => $this->categorieTree(),
            'gabarit'       => '',
            'nbProducts'    => '5',
            'nbJours'       => '5'
        );

        if (isset($_GET['auto_id'])) {
            $automatisation = ( new AutomatisationManager(new Wp_caller()) )->get_automatisation(sanitize_text_field($_GET['auto_id']));
            if ($automatisation) {
                $defautData['id']            = $automatisation->getId();
                $defautData['name']          = $automatisation->getName();
                $defautData['playlist']      = $automatisation->getPlaylist();
                $defautData['populaire']     = $automatisation->getHookSell();
                $defautData['new']           = $automatisation->getHookCreation();
                $defautData['priceMin']      = $automatisation->getPriceMin();
                $defautData['priceMax']      = $automatisation->getPriceMax();
                $defautData['categorieTree'] = $this->categorieTree($automatisation->getCategorie());
                $defautData['gabarit']       = $automatisation->getGabarit();
                $defautData['nbProducts']    = $automatisation->getNbProduit();
                $defautData['nbJours']       = $automatisation->getNbJours();
            }
        }

        return $defautData;
    }
}
