<?php

    require_once __DIR__ . "/../Classes/DigitalSignageFormBuilder.php";
    require_once __DIR__ . "/../Classes/Tools_DS4.php";
    require_once __DIR__ . "/../Kernel/Translations/DigitalSignageTranslate.php";
    require_once __DIR__ . "/../Classes/Wp_caller.php";
    require_once __DIR__ . "/../Kernel/API/Manager/DemandeManager.php";
    require_once __DIR__ . "/../Kernel/API/Manager/DigitalSignageException.php";
    require_once __DIR__ . "/../Kernel/API/Manager/ForfaitManager.php";
    require_once "DigitalSignageController.php";

    class ParametreController extends DigitalSignageController
    {
        public function generatePage()
        {
            $this->route();
        }

        private function route() {
			if (isset($_POST)) {
				if (sizeof($_POST) >0) {
					check_admin_referer( 'ds4_form_nonce' );
				}
			}
            try {
                $forfait = ForfaitManager::instance()->getForfait(ForfaitManager::instance()->getToken(), true);

                $this->handleDisqueFreeSpaceFormResponse();
                $this->handleYoutubeFormResponse();
                $this->handleWatermarkFormResponse();
                $this->handleResolutionFormResponse();

                // Deconnéxion de l'utilisateur
                $form = new DigitalSignageFormBuilder();
                $form->addExtraLink(DigitalSignageTranslate::getTraduction("Deconnexion"), $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'], "DigitalSignage4_logout", true, false);
                if ($form->submitExtraLink("DigitalSignage4_logout")) {
                    Wp_caller::getInstance()->delete_data(Wp_caller::FORFAIT);
                    Tools_DS4::redirectAdmin('DigitalSignageSettings');
                }

                $moduleInfos = Tools_DS4::getModuleInformations();
                $comtpeOnlineDs4Link = (!$forfait) ? "" : DigitalSignageTranslate::getTraduction("Compte_online_ds4") . "<a target='_blank' href='" . Tools_DS4::getAcaciaRedirectionPageUrl("account&accountId=" . $forfait->getCompte()->getId() . "&forfaitId=" . $forfait->getId()) . "'> " . DigitalSignageTranslate::getTraduction("Cliquez_ici") . "</a>";

                //Affichage de la vue de connexion
                $this->assign(array(
                    'pluginName'          => $moduleInfos['Name'], //name du module
                    'pluginurl'           => $moduleInfos['PluginURI'], //url du module
                    'pluginVersion'       => $moduleInfos['Version'], //Version du module
                    'pluginAuthor'        => $moduleInfos['AuthorName'], //author du module
                    'pluginAuthorUrl'     => $moduleInfos['AuthorURI'], //author url du module
                    'comtpeOnlineDs4'     => $comtpeOnlineDs4Link,
                    'actualiteUrl'        => DigitalSignageTranslate::getTraduction("Actualitees_site", Tools_DS4::getAcaciaRedirectionPageUrl("actu")),
                    //Cliquez_ici
                    'formConnection'      => $this->formConnexion(),
                    'formLogout'          => $form, // Déconnexion
                    'forfait'             => $forfait,
                    'resolution'          => Wp_caller::getInstance()->get_data(Wp_caller::RESOLUTION),
                    'compte'              => (!$forfait) ? "" : $forfait->getCompte(),
                    'urlAndNameForm'      => $this->formSetUrlAndSiteName(),
                    'prixDisplaySelector' => $this->formPrixDisplaySelector(),

                    //Changement url et nom du site pour les videos
                    'espaceDisk'          => array( // Variable pour formulaire d'espace disk
                                                    'totalFreeSpace' => round(disk_free_space("/") / 1024 / 1024 / 1024),
                                                    'totalDiskSpace' => round(disk_total_space("/") / 1024 / 1024 / 1024),
                                                    'currentLimit'   => $this->getCurrentSpaceSafe(),
                    ),
                    'watermark'           => $this->getCurrentWatermark(),// formulaire de création du watermark
                    'youtubeData'		  => $this->getYoutubeData(),
                    'youtubeAPIUrl'		=> API_Linker::API_URL . 'Youtube/',
                    'placements'          => $this->placementForm(), // Placement des videos a afficher automatiquement

                ));
            } catch (DigitalSignageException $e) {
                $e->echoError();
            }

            $this->setWPTemplate("Parametres/parametres");
        }

        private function formConnexion()
        {
            $form = new DigitalSignageFormBuilder("formualireDeConnexion", DigitalSignageTranslate::getTraduction("Connexion"));

            //Ajout des champs du formulaire
            $form->addChamp($form->generateField()->setId("userToken")->setLabel(DigitalSignageTranslate::getTraduction("Entrer_token_connexion"))->setName("userToken")->setType("text")->setValue(""));

            //ajout de l'oubli de mot de passe et de la création de contre

            try {
                $forfait = ForfaitManager::instance()->getForfait(ForfaitManager::instance()->getToken(), true);
                if ($forfait) {
                    $form->addExtraLink(DigitalSignageTranslate::getTraduction("Creer_compte_ds4"), Tools_DS4::getAcaciaRedirectionPageUrl("newAccount"));
                    $form->addExtraText("<br>" . DigitalSignageTranslate::getTraduction("Credit_dispo_trial") . ":" . ($forfait->getCredit() - $forfait->getCreditUsedPeriod()));
                }
            } catch (DigitalSignageException $e) {
            }

            $form->addExtraText(DigitalSignageTranslate::getTraduction("Actualitees_site", Tools_DS4::getAcaciaRedirectionPageUrl("actu")));

            //Récuperation du submit
            if ($form->isSubmit()) {
                $token = $form->getDatas();
                $token = $token['userToken'];

                try {
                    ForfaitManager::instance()->clearUserMessages();
                    $user = ForfaitManager::instance()->getForfait($token, true);

                    if ($user) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Connexion_compte_etablie");
                        Wp_caller::getInstance()->save_data(Wp_caller::FORFAIT, $user);
                        $_SESSION['Errors'] = array();
                        Tools_DS4::redirectAdmin("DigitalSignageHome");
                    } else {
                        $_SESSION['Errors'] = array_merge((isset($_SESSION['Errors'])) ? $_SESSION['Errors'] : array(), ForfaitManager::instance()->getUserMessages());
                    }
                } catch (DigitalSignageException $e) {
                    $e->echoError();
                }
            }

            return $form;
        }

        /**
         * Récuperation de la limite d'espace disque
         */
        private function handleDisqueFreeSpaceFormResponse()
        {
            if (isset($_POST)) {
                if (isset($_POST['setDiskSpaceSafe'])) {
                    if (isset($_POST['activerLaSecurisation'])) {
                        $limit = sanitize_text_field($_POST['limitSpace']);
                        unset($_POST['setDiskSpaceSafe'], $_POST['limitSpace'], $_POST['activerLaSecurisation']);
                    } else {
                        $limit = 0;
                    }
                    if (Wp_caller::getInstance()->get_data(Wp_caller::DISK_FREE_SPACE) == $limit) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_inchangé");
                    } else {
                        if (Wp_caller::getInstance()->save_data(Wp_caller::DISK_FREE_SPACE, $limit)) {
                            $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Espace_disque_save");
                        } else {
                            $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Espace_disque_non_save");
                        }
                    }

                    $this->refreshParametresPage();
                }
            }
        }

        /**
         * Récupération du watermark et son emplacement
         */
        private function handleWatermarkFormResponse()
        {
            if (isset($_POST)) {
                if (isset($_POST['WaterMark_button'])) {
                    $watermarkUploaded = false;
                    $newWatermarkFileUploaded = false;
                    $uploaddir = Tools_DS4::getModuleImgDir();
                    $uploadfile = $uploaddir . "watermark.png";
					
					

                    if (isset($_FILES)) {
                        if (isset($_FILES['Watermark'])) {
                            if ($_FILES['Watermark']['size'] > 0) {
                                //configurer options wp_handle_upload
                                $overrides = [ 'test_form' => false ];
                                //appeler wp_handle_upload
                                $movefile = wp_handle_upload($_FILES['Watermark'] , $overrides );
                                //si le fichier est correct, le déplacer dans $uploadfile
                                if ( $movefile && empty( $movefile['error'] ) ) {
                                    $file_path = $movefile['file'];
                                    chmod($uploadfile, 0777);
                                    unlink($uploadfile);
                                    copy($file_path,$uploadfile);
                                    $newWatermarkFileUploaded = true;
                                    chmod($uploadfile, 0777);
                                    $watermarkUploaded = true;
                                }
                                //$watermarkUploaded = move_uploaded_file($_FILES['Watermark']['tmp_name'], $uploadfile);
                            } else {
                                $watermarkUploaded = false; // aucun changement de watermark demandé
                            }
                        }
                    }

                    $watermarkDatas = array(
                        "watermark_active" => isset($_POST['activ_watermark']),
                        "watermark_place"  => $_POST['place'],
                    );

                    if ($watermarkDatas['watermark_active'] && !$watermarkUploaded) {
                        $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("image_erreur_download");
                        $this->refreshParametresPage();
                    } elseif ($watermarkDatas['watermark_active'] == false) {
                        unlink($uploadfile);
                    }

                    if (Wp_caller::getInstance()->get_data(Wp_caller::WATERMARK) == $watermarkDatas && !$newWatermarkFileUploaded) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_inchangé");
                    } else {
                        if (Wp_caller::getInstance()->save_data(Wp_caller::WATERMARK, $watermarkDatas)) {
                            $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Filigrane_save");
                        } else {
                            $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Filigrane_non_save");
                        }
                    }

                    $this->refreshParametresPage();
                }
            }
        }

        /**
         * @return DigitalSignageFormBuilder
         */
        private function formSetUrlAndSiteName()
        {
            $form = new DigitalSignageFormBuilder("urlForm", DigitalSignageTranslate::getTraduction("Enregistrer"));

            $currentInfos = $this->getCurrentInfoSite();

            $form->addChamp($form->generateField()->setId("urlSite")->setLabel(DigitalSignageTranslate::getTraduction("Url_site"))->setName("urlSite")->setType("url")->setValue($currentInfos['urlSite']));

            $form->addChamp($form->generateField()->setId("nameSite")->setLabel(DigitalSignageTranslate::getTraduction("Nom_site"))->setName("nameSite")->setType("text")->setValue($currentInfos['nameSite']));

            if ($form->isSubmit()) {
                $datas = $form->getDatas();

                if (Wp_caller::getInstance()->get_data(Wp_caller::SITE) == $datas) {
                    $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_inchangé");
                } else {
                    if (Wp_caller::getInstance()->save_data(Wp_caller::SITE, $datas)) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_save");
                    } else {
                        $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Parametres_non_save");
                    }
                }

                $this->refreshParametresPage();
            }

            return $form;
        }

        private function getCurrentInfoSite()
        {
            if ($DigitalSignage4_infos = Wp_caller::getInstance()->get_data(Wp_caller::SITE)) {
                if ($DigitalSignage4_infos != "1") {
                    if (isset($DigitalSignage4_infos['urlSite'], $DigitalSignage4_infos['nameSite'])) {
                        return $DigitalSignage4_infos;
                    }
                }
            }

            return array(
                "urlSite"  => get_site_url(),
                "nameSite" => get_bloginfo('name'),
            );
        }

        private function getYoutubeData()
        {
            if (Wp_caller::getInstance()->get_data(Wp_caller::YOUTUBE_JSON)) {
                return Wp_caller::getInstance()->get_data(Wp_caller::YOUTUBE_JSON);
            }

            return array(
                "youtube_active" => false,
                "youtube_nb_max_envoi_jour" => 10,
                "youtube_json"  => 'coucou',
            );
        }

        private function getCurrentSpaceSafe()
        {
            if (Wp_caller::getInstance()->get_data(Wp_caller::DISK_FREE_SPACE)) {
                return Wp_caller::getInstance()->get_data(Wp_caller::DISK_FREE_SPACE);
            }

            return 0;
        }


        private function getCurrentWatermark()
        {
            if ($DigitalSignage4_watermark = Wp_caller::getInstance()->get_data(Wp_caller::WATERMARK)) {
                if ($DigitalSignage4_watermark !== "1") {
                    if (isset($DigitalSignage4_watermark['watermark_active'], $DigitalSignage4_watermark['watermark_place'])) {
                        return $DigitalSignage4_watermark;
                    }
                }
            }

            return array(
                "watermark_active" => false,
                "watermark_place"  => '',
            );
        }


        private function placementForm()
        {
            $DigitalSignage4_infos = Wp_caller::getInstance()->get_data(Wp_caller::PLACEMENT);

            if (!is_array($DigitalSignage4_infos)) {
                $DigitalSignage4_infos = array($DigitalSignage4_infos);
            }

            $form = new DigitalSignageFormBuilder("placementForm", DigitalSignageTranslate::getTraduction("Enregistrer"));



            $form->addChamp($form->generateField()->setId("placement_1")->setName("placement_1")->setType("checkbox")->setChecked(isset($DigitalSignage4_infos['placement_1'])));

            $form->addChamp($form->generateField()->setId("placement_2")->setName("placement_2")->setType("checkbox")->setChecked(isset($DigitalSignage4_infos['placement_2'])));

            $form->addChamp($form->generateField()->setId("placement_3")->setName("placement_3")->setType("checkbox")->setChecked(isset($DigitalSignage4_infos['placement_3'])));

            $form->addChamp($form->generateField()->setId("placement_4")->setName("placement_4")->setType("checkbox")->setChecked(isset($DigitalSignage4_infos['placement_4'])));

            $form->addChamp($form->generateField()->setId("placement_5")->setName("placement_5")->setType("checkbox")->setChecked(isset($DigitalSignage4_infos['placement_5'])));

            $form->addChamp($form->generateField()->setId("placement_6")->setName("placement_6")->setType("checkbox")->setChecked(isset($DigitalSignage4_infos['placement_6'])));


            if ($form->isSubmit()) {
                $datas = $form->getDatas();

                if (Wp_caller::getInstance()->get_data(Wp_caller::PLACEMENT) == $datas) {
                    $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_inchangé");
                } else {
                    if (Wp_caller::getInstance()->save_data(Wp_caller::PLACEMENT, $datas)) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Emplacement_save");
                    } else {
                        $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Emplacement_non_save");
                    }
                }

                $this->refreshParametresPage();
            }

            return $form;
        }

        private function refreshParametresPage()
        {
            header('Location: ' . $_SERVER['REQUEST_URI']);
            exit();
        }

        private function formPrixDisplaySelector()
        {
            if (!$DigitalSignage4_prix_display = Wp_caller::getInstance()->get_data(Wp_caller::PRIX_FORMAT)) {
                $DigitalSignage4_prix_display = 0;
                Wp_caller::getInstance()->save_data(Wp_caller::PRIX_FORMAT, $DigitalSignage4_prix_display);
            }

            $device = Tools_DS4::getWooCommerceDevice();
            $pleinPrice = 10;
            $floatPrice = 99;
            $separator = ',';
            $separatorDot = '.';


            ob_start(); ?>
            <h2><?php echo DigitalSignageTranslate::getTraduction("Affichage du prix") ?> </h2>
            <table class="priceFormat" style="font-size: 1.2em;">
                <tr>

                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 0) ? "checked" : "" ?>
                                                                    value="0"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separatorDot . "</strong>" . $floatPrice ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 1) ? "checked" : "" ?>
                                                                    value="1"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separatorDot . "</strong>" . "<sup>" . $floatPrice . "</sup>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 2) ? "checked" : "" ?>
                                                                    value="2"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separatorDot . "</strong>" . "<sub>" . $floatPrice . "</sub>" ?>
                        </label>
                    </td>

                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 3) ? "checked" : "" ?>
                                                                    value="3"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separator . "</strong>" . $floatPrice ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 4) ? "checked" : "" ?>
                                                                    value="4"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separator . "</strong>" . "<sup>" . $floatPrice . "</sup>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 5) ? "checked" : "" ?>
                                                                    value="5"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separator . "</strong>" . "<sub>" . $floatPrice . "</sub>" ?>
                        </label>
                    </td>

                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 6) ? "checked" : "" ?>
                                                                    value="6"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<sup>" . $floatPrice . "</sup>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 7) ? "checked" : "" ?>
                                                                    value="7"/> <?php echo "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $pleinPrice . "<sub>" . $floatPrice . "</sub>" ?>
                        </label><br>
                    </td>


                </tr>

                <tr>


                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 8) ? "checked" : "" ?>
                                                                    value="8"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separatorDot . "</strong>" . $floatPrice . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 9) ? "checked" : "" ?>
                                                                    value="9"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separatorDot . "</strong>" . "<sup>" . $floatPrice . "</sup>" . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 10) ? "checked" : "" ?>
                                                                    value="10"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separatorDot . "</strong>" . "<sub>" . $floatPrice . "</sub>" . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label>
                    </td>

                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 11) ? "checked" : "" ?>
                                                                    value="11"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separator . "</strong>" . $floatPrice . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 12) ? "checked" : "" ?>
                                                                    value="12"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separator . "</strong>" . "<sup>" . $floatPrice . "</sup>" . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 13) ? "checked" : "" ?>
                                                                    value="13"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;'>" . $separator . "</strong>" . "<sub>" . $floatPrice . "</sub>" . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label>
                    </td>

                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 14) ? "checked" : "" ?>
                                                                    value="14"/> <?php echo $pleinPrice . "<sup>" . $floatPrice . "</sup>" . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 15) ? "checked" : "" ?>
                                                                    value="15"/> <?php echo $pleinPrice . "<sub>" . $floatPrice . "</sub>" . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" ?>
                        </label><br>
                    </td>


                </tr>

                <tr>
                    <td>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 16) ? "checked" : "" ?>
                                                                    value="16"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . $floatPrice ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 17) ? "checked" : "" ?>
                                                                    value="17"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . "<sup>" . $floatPrice . "</sup>" ?>
                        </label><br>
                        <label style="font-weight: inherit;"><input type="radio"
                                                                    name="format" <?php echo ($DigitalSignage4_prix_display == 18) ? "checked" : "" ?>
                                                                    value="18"/> <?php echo $pleinPrice . "<strong style='margin: 0px 3px;font-weight: 600;'>" . $device . "</strong>" . "<sub>" . $floatPrice . "</sub>" ?>
                        </label>
                    </td>
                    <td></td>
                    <td></td>
                </tr>


            </table>

            <?php

            $formTableau = ob_get_clean();

            $form = new DigitalSignageFormBuilder("priceFormatForm", DigitalSignageTranslate::getTraduction("Enregistrer"));
            $form->setClass("specialTable");
            $form->setHtml($formTableau);

            if ($form->isSubmit()) {
                $datas = $form->getDatas();
                $datas = $datas['format'];

                if (Wp_caller::getInstance()->get_data(Wp_caller::PRIX_FORMAT) == $datas) {
                    $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_save");
                } else {
                    if (Wp_caller::getInstance()->save_data(Wp_caller::PRIX_FORMAT, $datas)) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_save");
                    } else {
                        $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Parametres_non_save");
                    }
                }

                $this->refreshParametresPage();
            }

            return $form;
        }
        private function handleYoutubeFormResponse()
        {
            if (isset($_POST)) {
                if (isset($_POST['Youtube_button'])) {
                    $youtubeActive = false;
                    $youtubeDatas = array(
                        "youtube_active" => isset($_POST['activ_youtube']),
                        "youtube_json"  => $_POST['youtube_json'],
                        "youtube_nb_max_envoi_jour"  => sanitize_text_field($_POST['youtube_nb_max_envoi_jour']),
                    );
                    //pousser a l'api le nouveau youtube_nb_max_envoi_jour


                    ForfaitManager::instance()->update_compteur_youtube_max(ForfaitManager::instance()->getToken(), sanitize_text_field($_POST['youtube_nb_max_envoi_jour']));

                    if (Wp_caller::getInstance()->save_data(Wp_caller::YOUTUBE_JSON, $youtubeDatas)) {
                        $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Youtube_save");
                    } else {
                        $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Youtube_non_save");
                    }
                    $this->refreshParametresPage();
                }
            }
        }

        private function handleResolutionFormResponse()
        {
            if (isset($_POST['setResolution'])) {
                if (Wp_caller::getInstance()->get_data(Wp_caller::RESOLUTION) == $_POST['resolution'] || // Si les parametres so nt les meme que avant
                    Wp_caller::getInstance()->save_data(Wp_caller::RESOLUTION, $_POST['resolution']) // si les nouveaux parametres sont enregistrait
                ) {
                    $_SESSION['Success'][] = DigitalSignageTranslate::getTraduction("Parametres_save");
                } else {
                    $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Parametres_non_save");
                }
            }
        }
    }
