<?php

    require_once __DIR__ . "/../Classes/Tools_DS4.php";
    require_once __DIR__ . "/../Kernel/Translations/DigitalSignageTranslate.php";
    require_once __DIR__ . "/../Classes/Wp_caller.php";
    require_once __DIR__ . "/../Kernel/API/Entity/DemandeEntity.php";
    require_once __DIR__ . "/../Kernel/API/Entity/PlaylistEntity.php";
    require_once __DIR__ . "/../Kernel/API/Manager/DemandeManager.php";
    require_once __DIR__ . "/../Kernel/API/Manager/DigitalSignageException.php";
    require_once __DIR__ . "/../Kernel/API/Manager/PlaylistManager.php";

    class PlaylistsController extends DigitalSignageController
    {
        public function generatePage()
        {
            $this->route();
        }

        private function route()
        {
            if (isset($_GET['id_playlist'])) {
                $this->display_playlist();
            } else {
                $this->display_playlists();
            }
        }


        private function display_playlist()
        {
            try {
                $playlistM = new PlaylistManager(Wp_caller::getInstance());

                $this->handleUpdatePlaylistAjax();

                if (isset($_GET['loadVideos'], $_GET['start'], $_GET['stop'])) {
                    ob_get_clean();
                    $this->loadAutoPagination();
                }

                try {
                    $playlist = new PlaylistEntity();

                    if (isset($_GET['id_playlist']) && (!empty($_GET['id_playlist']) || strval($_GET['id_playlist']) == "0")) {
                        if ($playlistT = $playlistM->get_playlist(sanitize_text_field(sanitize_text_field($_GET['id_playlist'])))) {
                            $playlist = $playlistT;
                        }
                    }

                    $this->assign(
                        array(
                            'videoPlaylist' => $this->getVideoPlaylist($playlist),
                            'playlist'      => $playlist,
                            "moduleBaseUrl" => Tools_DS4::getModuleVideoUrl()
                        )
                    );
                } catch (DigitalSignageException $e) {
                    $e->echoError();
                }

                $this->setWPTemplate("Playlists/add_playlist");
            } catch (DigitalSignageException $e) {
                $e->echoError();
            }
        }

        private function handleUpdatePlaylistAjax()
        {
            if (isset($_POST['playlist_name'], $_POST['playlist_videos'])) {

                // Reste de buffer du module pour les reponse ajax
                ob_get_clean();

                try {
                    $playlistManager = new PlaylistManager(Wp_caller::getInstance());

                    // Récuperation de la methode demandé update si un ed existe ou add si un id est generé
                    $isUpdate = false;


                    if (isset($_GET['id_playlist']) && (!empty($_GET['id_playlist']) || strval($_GET['id_playlist']) == "0")) {
                        $id = sanitize_text_field($_GET['id_playlist']);

                        if ($playlistManager->get_playlist($id)) {
                            $isUpdate = true;
                        }
                    } else {
                        $id = PlaylistManager::set(Wp_caller::getInstance())->get_last_id() + 1;
                    }


                    $videosSaved = array_unique(json_decode(stripcslashes($_POST['playlist_videos']), true));

                    $playlist = new PlaylistEntity();
                    $playlist->set_active(true)
                        ->set_id($id)
                        ->set_limit(10)
                        ->set_title(sanitize_text_field(stripslashes($_POST['playlist_name'])))
                        ->set_videos($videosSaved);


                    if ($isUpdate) {
                        $playlistOld = PlaylistManager::set(Wp_caller::getInstance())->get_playlist($id);

                        if ($playlistOld->get_title() == $playlist->get_title() && $playlistOld->get_videos() == $playlist->get_videos()) {
                            die(DigitalSignageTranslate::getTraduction("Parametres_inchangé"));
                        }

                        $playlist->set_active($playlistOld->get_active());
                        $playlist->set_limit($playlistOld->get_limit());

                        if ($playlistManager->update_playlist($playlist)) {
                            die("ok");
                        } else {
                            die(DigitalSignageTranslate::getTraduction("Erreur_playlist_non_trouvé"));
                        }
                    } else {
                        if ($playlistManager->add_playlist($playlist)) {
                            die(json_encode(array("ok", $playlistManager->get_last_id())));
                        } else {
                            die(DigitalSignageTranslate::getTraduction("Playlist_non_save"));
                        }
                    }
                } catch (DigitalSignageException $e) {
                    $e->echoError();
                }
            }
        }

        private function deleteVideoFromPlaylist(
            $videos
        ) {
            $videosFinal = array();

            if (isset($_GET['id_playlist']) && $_GET['id_playlist'] != "") {
                try {
                    $playlist = PlaylistManager::set(Wp_caller::getInstance())->get_playlist(sanitize_text_field($_GET['id_playlist']));
                } catch (DigitalSignageException $e) {
                    $e->echoError();
                }
                if ($playlist) {
                    foreach ($videos as $video) {
                        if (!in_array($video->getIdDemande(), $playlist->get_videos())) {
                            $videosFinal[] = $video;
                        }
                    }
                }

                return $videosFinal;
            }

            return $videos;
        }

        /**
         * @param DemandeEntity $video
         * @return string
         */
        private function generateVideoVue($video)
        {
            if ($video->getFlag() == 'completed') {
                
                return ('<div id=\'' . $video->getIdDemande() . '\' class=\'add_playlist_video\'
                                             ondragstart=\'drag(event)\'>
											 
                                            <video style=\'max-height:141px;\' controls muted=\'muted\' preload=\'auto\' loop onloadedmetadata=\'addPlayOnHover(this)\'>
                                                <source src=\'' . $video->getVideoUrl() . '\'
                                                        type=\'video/mp4\'>
                                            </video>
                                            <div class=\'description_video\'>
                                                <span>' . $video->getVideoName() . '</span>
                                                <span class=\'material-icons\' id=\'button_' . $video->getIdDemande() . '\'
                                                      onclick=\'toggleVideoPlaylist(this)\'>add_circle_outline</span>
                                            </div>
                                        </div>');
            } else {
                return ('<div id=\'' . $video->getIdDemande() . '\' class=\'add_playlist_video\' draggable=\'true\'
                             ondragstart=\'drag(event)\'
                             style=\'display: flex;justify-content: center;flex-wrap: wrap;padding: 10px;color: white;\'
                             onclick=\'toggleVideoPlaylist(this)\'>
                            <span class=\'info\'>' . DigitalSignageTranslate::getTraduction('Video_cours_creation_playlist', DigitalSignageTranslate::getTraduction("Videos")) . '</span>
                            <div class=\'sablier\'></div>
                        </div>
                ');
            }
        }

        /**
         * @param PlaylistEntity $playlist
         *
         * @return string
         */
        private function getVideoPlaylist($playlist)
        {
            $videosIds = $playlist->get_videos();
            $videosString = "";
            foreach ($videosIds as $id) {
                $video = DemandeManager::set(Wp_caller::getInstance())->getLocalDemandes("SELECT * FROM %s WHERE `id_demande` =  $id ");
                if (isset($video[0]) && $video[0] instanceof DemandeEntity) {
                    $videosString = $videosString . $this->generateVideoVue($video[0]);
                }
            }

            return $videosString;
        }

        /**
         * affiche la page d'affichage des playlists
         */
        public function display_playlists()
        {
            try {
                $pc = new PlaylistManager(Wp_caller::getInstance());

                // si le formulaire est correct
                if (isset($_POST['id'], $_POST['etat'], $_POST['limit'])) {
                    ob_get_clean();

                    $playlist = $pc->get_playlist(sanitize_text_field($_POST['id']));

                    $playlist->set_limit(sanitize_text_field($_POST['limit']));
                    $playlist->set_active($_POST['etat'] === "true");

                    try {
                        if ($pc->update_playlist($playlist)) {
                            die("ok");
                        } else {
                            die(DigitalSignageTranslate::getTraduction("Update_impossible"));
                        }
                    } catch (Exception $e) {
                        die(DigitalSignageTranslate::getTraduction("Update_impossible"));
                    }
                }

                if (isset($_POST['id'], $_POST['delete'])) {
                    ob_get_clean();

                    if ($_POST['delete'] == "true") {
                        $playlistToDelete = $pc->get_playlist(sanitize_text_field($_POST['id']));

                        try {
                            if ($playlistToDelete != null && $pc->remove_playlist($playlistToDelete)) {
                                die("ok");
                            } else {
                                die(DigitalSignageTranslate::getTraduction("Delete_impossible"));
                            }
                        } catch (DigitalSignageException $e) {
                            $e->echoError();
                        }
                    }
                }

                $playlists = $pc->get_playlists();

                $this->assign(
                    array(
                        'playlists'       => $playlists,
                        "urlTraitement"   => 'admin.php?page=DigitalSignagePlaylists',
                        "urlModification" => 'admin.php?page=DigitalSignagePlaylists'
                    )
                );
            } catch (DigitalSignageException $e) {
                $e->echoError();
            }


            $this->setWPTemplate("Playlists/playlists");
        }

        private function loadAutoPagination()
        {
            $videoNamePatern = (isset($_GET['find'])) ? $_GET['find'] : "";


            $playlistVideosIds = array();

            if (isset($_GET['id_playlist']) && $_GET['id_playlist'] != "") {
                $playlistVideosIds = PlaylistManager::set(Wp_caller::getInstance())->get_playlist(sanitize_text_field($_GET['id_playlist']))->get_videos();
            }

            $videos = DemandeManager::set(Wp_caller::getInstance())->getLocalDemandes("SELECT * FROM %s WHERE `flag` = 'completed' AND `video_name` LIKE '%" . $videoNamePatern . "%' AND `id_demande` NOT IN ('" . implode("' , '", $playlistVideosIds) . "') LIMIT " . sanitize_text_field($_GET['stop']) . " OFFSET " . sanitize_text_field($_GET['start']));

            $itEnd = true;

            if ($videos) {
                $itEnd = false;
            }

            $videos = $this->deleteVideoFromPlaylist($videos);

            $videosString = ($itEnd) ? "" : " ";

            foreach ($videos as $video) {
                $videosString = $videosString . $this->generateVideoVue($video);
            }


            die(json_encode(array("ok", htmlentities($videosString))));
        }
    }
