<?php

    require_once __DIR__ . "/../../Classes/Wp_caller.php";
    require_once __DIR__ . "/../../Kernel/API/Entity/AutomatisationEntity.php";
    require_once __DIR__ . "/../../Kernel/API/Entity/DemandeEntity.php";
    require_once __DIR__ . "/../../Kernel/API/Manager/AutomatisationManager.php";
    require_once __DIR__ . "/../../Kernel/API/Manager/DemandeManager.php";
    require_once __DIR__ . "/../../Kernel/API/Manager/DigitalSignageException.php";
    require_once __DIR__ . "/../../Kernel/API/Manager/GabaritManager.php";
    require_once __DIR__ . "/../../Kernel/API/Manager/PlaylistManager.php";
    require_once __DIR__ . "/../../Classes/CreationVideoSpecialDataProvider.php";

    class AutomatisationHookControllerCreation
    {
        private $wp_caller = null;
        private $demande_manager = null;
        private $gabarit_manager = null;

        /**
         * @param null $wp_caller
         */
        public function __construct()
        {
            $this->wp_caller = new Wp_caller();
            $this->demande_manager = new DemandeManager($this->wp_caller);
            $this->gabarit_manager = GabaritManager::instance();
        }

        /**
         * @param string $newProductStatus
         * @param string $oldProductStatus
         * @param WP_Post $product
         *
         * @return void
         */
        public function handleProductChangeStatus($newProductStatus, $oldProductStatus, $product)
        {
            if ($product->post_type == "product" && $newProductStatus == "publish" && $oldProductStatus != "publish") { // a decommenter lors du passage en prod
                //if ( $product->post_type == "product" && $newProductStatus == "publish" ) {
                $automatisations = $this->getAutomatisation();
                foreach ($automatisations as $automatisation) {
                    $this->automatisationJob($automatisation, $product);
                }
            }
        }

        /**
         * @return AutomatisationEntity[] array
         */
        private function getAutomatisation()
        {
            /**         * @var AutomatisationEntity[] $allAutomatisations */
            $allAutomatisations = ($this->wp_caller->get_data("DigitalSignage_automatisation")) ?: array();

            return array_filter(
                $allAutomatisations,
                function ($automatisation) {
                    $isHookCreation = filter_var($automatisation->getHookCreation(), FILTER_VALIDATE_BOOLEAN);
                    $isActive = filter_var($automatisation->isActive(), FILTER_VALIDATE_BOOLEAN);
                    return $isHookCreation && $isActive;
                }
            );
        }

        /**
         * @param AutomatisationEntity $automatisation
         * @param WP_Post $wordPressPost
         *
         * @return boolean
         */
        public function automatisationJob($automatisation, $wordPressPost)
        {
            $wooCommerceProduct = new WC_Product($wordPressPost->ID);

            $priceIsGood = $this->checkAutomatisationPriceFilter($automatisation, $wooCommerceProduct);
            $categorieIsGood = $this->checkAutomatisationCategories($automatisation, $wooCommerceProduct);

            if ($priceIsGood && $categorieIsGood) {
                $videoAlreadyCreated = $this->demande_manager->getLocalDemandes("SELECT * FROM %s WHERE `gabarit` = " . $automatisation->getGabarit() . " AND `product_id` = " . $wooCommerceProduct->get_id() . " ORDER BY `id_demande` DESC LIMIT 1;");

                if (!empty($videoAlreadyCreated)) {
                    $this->addDemandeInPlaylist($videoAlreadyCreated[0], $automatisation->getPlaylist());
                    $this->wp_caller->save_data(Wp_caller::AUTOMATISATION_TRACE, date("Y-m-d H:i:s"));
                } else {
                    $datasForPostDemande = $this->getDatasForPostDemande($automatisation, $wooCommerceProduct, $wordPressPost);
                    $postDemandeResponse = $this->postVideoToApi($datasForPostDemande);

                    if ($postDemandeResponse && $this->addDemandeInPlaylist($postDemandeResponse, $automatisation->getPlaylist())) {
                        $automatisation->setCreated($automatisation->getCreated() + 1);
                        AutomatisationManager::set($this->wp_caller)->update_automatisation($automatisation);
                        $this->wp_caller->save_data(Wp_caller::AUTOMATISATION_TRACE, date("Y-m-d H:i:s"));
                    }
                }
            }
        }

        /**
         * @param AutomatisationEntity $automatisation
         * @param WC_Product $wooCommerceProduct
         *
         * @return boolean
         */
        private function checkAutomatisationPriceFilter($automatisation, $wooCommerceProduct)
        {
            $autoPriceMin = intval($automatisation->getPriceMin());
            $autoPirceMax = intval($automatisation->getPriceMax());

            if ($autoPriceMin == -1 && $autoPirceMax == -1) {
                return true;
            } elseif ($autoPriceMin >= 0 && $autoPirceMax == -1) {
                return $wooCommerceProduct->get_price() >= $autoPriceMin;
            } elseif ($autoPriceMin >= 0 && $autoPirceMax >= 0) {
                return $wooCommerceProduct->get_price() >= $autoPriceMin && $wooCommerceProduct->get_price() <= $autoPirceMax;
            }

            return false;
        }

        /**
         * @param AutomatisationEntity $automatisation
         * @param WC_Product $wooCommerceProduct
         *
         * @return boolean
         */
        private function checkAutomatisationCategories($automatisation, $wooCommerceProduct)
        {
            $productCategories = $wooCommerceProduct->get_category_ids();
            $automatisationCategorie = $automatisation->getCategorie();
            $categorieMatch = empty($automatisationCategorie); //Si aucune categorie n'est set dans l'automatisation alors le match par defaut et a true
            foreach ($productCategories as $productCategorie) {
                if (in_array($productCategorie, $automatisationCategorie)) {
                    $categorieMatch = true;
                }
            }

            return $categorieMatch;
        }

        /**
         * @param DemandeEntity $demande
         * @param $playlistId
         *
         * @return boolean
         */
        private function addDemandeInPlaylist($demande, $playlistId)
        {
            try {
                $playlistManager = new PlaylistManager($this->wp_caller);
                $playlist = $playlistManager->get_playlist($playlistId);
                if ($playlist) {
                    $videosPlaylist = $playlist->get_videos();
                    $videoPlaylist = $this->removeArrayValue($videosPlaylist, $demande->getIdDemande());
                    array_unshift($videoPlaylist, $demande->getIdDemande());
                    $playlist->set_videos($videoPlaylist);
                    $playlistManager->update_playlist($playlist);
                }

                return true;
            } catch (DigitalSignageException $e) {
                return false;
            }
        }

        private function removeArrayValue($array, $value)
        {
            if (($key = array_search($value, $array)) !== false) {
                unset($array[$key]);
            }

            return $array;
        }

        /**
         * @param array $datas
         *
         * @return false|DemandeEntity
           id_lot = id_lot+1
         */
        public function postVideoToApi($datas, $id_lot=1)
        {
            global $wpdb;

            $video = new DemandeEntity();

            $video->setData($datas);
            $video->setGabarit($datas['gabarit']);
            $video->setDateBegin(date('y-m-d H:i:s'));
            $video->setDateEnd(date("y-m-d H:i:s"));
            $video->setVideoComment("");
            $video->setVideoName((isset($datas['produit_libelle'])) ? $datas['produit_libelle'] : DigitalSignageTranslate::getTraduction("Default_video_name"));
            $video->setAutomatique($id_lot);
            $video->setDateDemande(date("Y-m-d H:i:s"));
            $video->setProductId($datas['product_id']);
            $video->setDownloaded("0");

            $specialChampsManager = new CreationVideoSpecialDataProvider();
            $data_youtube = $specialChampsManager->getyoutubevideo($datas['product_id']);
            $video->setYoutubeData(json_encode($data_youtube));
            
            //poste la création de video
            try {
                $demande = $this->demande_manager->postDemande($video);
                if ($demande) {
                    if ($this->wp_caller->execute_video_insert(
                        "INSERT INTO `%s` (`id_demande`,                       `data`,                        `flag`,                        `video_name`,                      `video_comment`,                       `date_begin`,                            `automatique`,                        `date_end`,                       `date_demande`,                       `gabarit`,                        `video_url`,                       `video_hash`,                       `product_id`,`youtube_data`) VALUES
                                               (" . $demande->getIdDemande() . ",        \"" . $wpdb->_real_escape($demande->getData()) . "\", \"" . $demande->getFlag() . "\", \"" . $demande->getVideoName() . "\", \"" . $demande->getVideoComment() . "\", \"" . $demande->getDateBegin() . "\", \"" . $demande->getAutomatique() . "\", \"" . $demande->getDateEnd() . "\", \"" . $demande->getDateDemande() . "\", \"" . $demande->getGabarit() . "\", \"" . $demande->getVideoUrl() . "\", \"" . $demande->getVideoHash() . "\", \"" . $demande->getProductId() . "\", \"" .$wpdb->_real_escape($demande->getYoutubeData()). "\") "
                    )) {
                        return $demande;
                    }
                }

                return false;
            } catch (DigitalSignageException $e) {
                return false;
            }
        }


        /**
        * @param AutomatisationEntity $automatisation
        * @param WC_Product $wooCommerceProduct
        * @param WP_Post $wordPressPost
        *
        * @return array
        */
        public function getDatasForPostDemandeAvecGabarit($Gabarit_param, $wooCommerceProduct, $wordPressPost)
        {
            //file_put_contents('debug_ag.txt','getDatasForPostDemandeAvecGabarit'."\r\n",FILE_APPEND);
            //detecter si personnalisation du gabarit
            //si oui modifie le datasForPostDemande!!!!!
            $gabarit = $this->gabarit_manager->getGabarit($Gabarit_param);




            $datas = array();
            $imageCompteur = 1;
            //foreach ($gabarit->getChamps() as $champ) {
            $champs__ =$gabarit->initCustomChamp();
            foreach ($champs__ as $champ) {
                if ($champ['type'] == 'picture') {
                    if (strpos($champ['default'], ';')!==false) {//AG je ne peux pas faire autrement
                        $datas[$champ['name']] = $champ['default'];
                        $tab_temp = array();
                        $tab_temp = explode(';', $champ['default']);
                        if (count($tab_temp)>=2) {
                            $datas[$champ['name']] =$tab_temp[1];
                        }


                        //file_put_contents('debug_ag.txt',$champ['name'].' '.$champ['default']."\r\n",FILE_APPEND);
                        //file_put_contents('debug_ag.txt','ICI RESULTAT:|'.$datas[$champ['name']]."|"."\r\n",FILE_APPEND);
                    } else {
                        if ($champ['default']!=="") {
                            //il faut detecter les mots clefs images!!! ex: product01PictureUrl01 !!!
                            //file_put_contents('debug_ag.txt',$champ['name'].' '.$champ['default']."\r\n",FILE_APPEND);
                            $specialChampsManager = new CreationVideoSpecialDataProvider();
                            $callableFunctionData = array($specialChampsManager, $champ['default']);
                            if (is_callable($callableFunctionData)) {
                                $tab_temp = array();
                                $tab_temp = explode(';', call_user_func($callableFunctionData));
                                //$datas[$champ['name']] = call_user_func($callableFunctionData);
                                $datas[$champ['name']] =$this->getDatasPictureForPostDemande($wooCommerceProduct, $this->get_number_picture_from_name($champ['default']));
                                if (count($tab_temp)>=2) {
                                    $datas[$champ['name']] = $tab_temp[1];
                                }
                            } else {
                                $datas[$champ['name']] = $this->getDatasPictureForPostDemande($wooCommerceProduct, $this->get_number_picture_from_name($champ['default']));
                            }
                        } else {
                            $datas[$champ['name']] = $this->getDatasPictureForPostDemande($wooCommerceProduct, $imageCompteur);
                            $imageCompteur += 1;
                        }
                    }
                } else {
                    $champ_name = $champ['wordpress_champ_name'];
					
					if ($champ_name=='IA_description') {
						//il faut pousser dans $datas[$champ['name']] 
						//le retour de l'api AI
						$specialChampsManager = new CreationVideoSpecialDataProvider();
						$datas[$champ['name']] = $specialChampsManager->IA_description($champ['ia_question'],$wooCommerceProduct->get_id());
						
					} else {
						$datas[$champ['name']] = $this->get_data_from_champ_name($wooCommerceProduct, $champ_name, $champ['default']);
					}
                }
            }

            $datas['gabarit'] = $Gabarit_param;
            $datas['produit_libelle'] = $wooCommerceProduct->get_name();
            $datas['product_id'] = $wooCommerceProduct->get_id();

            return $datas;
        }

        private function get_data_from_champ_name($wooCommerceProduct, $champ_name, $default)
        {
            $retour =$default;
            $callableFunctionData = array($wooCommerceProduct, 'get_' . $champ_name);
            if (is_callable($callableFunctionData)) {
                $retour = call_user_func($callableFunctionData);
            } else {
                if ($champ_name=='first_category') {
                    $terms =  get_the_terms($wooCommerceProduct->get_id(), 'product_cat');
                    if ($terms && ! is_wp_error($terms)) {
                        $retour = $terms[0]->name;
                    } else {
                        $retour = "";
                    }
                } else {
                    if ($champ_name=='pourcent_reduc') {
                        $retour="";
                        $productDatas = $wooCommerceProduct->get_data();
                        if ($productDatas['regular_price'] ==$productDatas['price']) {
                            $retour="0%";
                        } else {
                            if ($productDatas['regular_price'] >0) {
                                $retour = "-".round(($productDatas['price'] * 100) / $productDatas['regular_price'])."%";
                            }
                        }
                    } else {
                        $specialChampsManager = new CreationVideoSpecialDataProvider();
                        $callableFunctionData = array($specialChampsManager, $champ_name);
                        if (is_callable($callableFunctionData)) {
                            $retour = call_user_func($callableFunctionData);
                        }
                    }
                }
            }
            return $retour;
        }



        /**
         * @param AutomatisationEntity $automatisation
         * @param WC_Product $wooCommerceProduct
         * @param WP_Post $wordPressPost
         *
         * @return array
         */
        private function getDatasForPostDemande($automatisation, $wooCommerceProduct, $wordPressPost)
        {
            $gabarit = $this->gabarit_manager->getGabarit($automatisation->getGabarit());
            $datas = array();
            $imageCompteur = 1;
            $champs__ = $gabarit->initCustomChamp();
            foreach ($champs__ as $champ) {
                if ($champ['type'] == 'picture') {
                    if (strpos($champ['default'], ';')!==false) {//AG je ne peux pas faire autrement
                        $datas[$champ['name']] = $champ['default'];
                        $tab_temp = array();
                        $tab_temp = explode(';', $champ['default']);
                        if (count($tab_temp)>=2) {
                            $datas[$champ['name']] =$tab_temp[1];
                        }
                    } else {
                        //il faut detecter les mots clefs images!!! ex: product01PictureUrl01 !!!
                        if ($champ['default']!=="") {
                            //il faut detecter les mots clefs images!!! ex: product01PictureUrl01 !!!
                            $specialChampsManager = new CreationVideoSpecialDataProvider();
                            $callableFunctionData = array($specialChampsManager, $champ['default']);
                            if (is_callable($callableFunctionData)) {
                                $tab_temp = array();
                                $tab_temp = explode(';', call_user_func($callableFunctionData));
                                $datas[$champ['name']] =$this->getDatasPictureForPostDemande($wooCommerceProduct, $this->get_number_picture_from_name($champ['default']));
                                if (count($tab_temp)>=2) {
                                    $datas[$champ['name']] = $tab_temp[1];
                                }
                            } else {
                                $datas[$champ['name']] = $this->getDatasPictureForPostDemande($wooCommerceProduct, $this->get_number_picture_from_name($champ['default']));
                            }
                        } else {
                            $datas[$champ['name']] = $this->getDatasPictureForPostDemande($wooCommerceProduct, $imageCompteur);
                            $imageCompteur += 1;
                        }
                    }
                } else {
                    $champ_name = $champ['wordpress_champ_name'];
					

					if ($champ_name=='IA_description') {
						
						//il faut pousser dans $datas[$champ['name']] 
						//le retour de l'api AI
						$specialChampsManager = new CreationVideoSpecialDataProvider();
						$datas[$champ['name']] = $specialChampsManager->IA_description($champ['ia_question'],$wooCommerceProduct->get_id());
						
					} else {
						$datas[$champ['name']] = $this->get_data_from_champ_name($wooCommerceProduct, $champ_name, $champ['default']);
					}
                }
            }

            $datas['gabarit'] = $automatisation->getGabarit();
            $datas['produit_libelle'] = $wooCommerceProduct->get_name();
            $datas['product_id'] = $wooCommerceProduct->get_id();

            return $datas;
        }


        private function get_number_picture_from_name($name_picture)
        {
            switch ($name_picture) {
                case "product01PictureUrl01":
                    return 1;
                    break;
                case "product02PictureUrl01":
                    return 2;
                    break;
                case "product03PictureUrl01":
                    return 3;
                    break;
                case "product04PictureUrl01":
                    return 4;
                    break;
                case "product05PictureUrl01":
                    return 5;
                    break;
                case "product06PictureUrl01":
                    return 6;
                    break;
                case "product07PictureUrl01":
                    return 7;
                    break;
                case "product08PictureUrl01":
                    return 8;
                    break;
                case "product09PictureUrl01":
                    return 9;
                    break;
                case "product10PictureUrl01":
                    return 10;
                    break;
                default:
                    return 1;

            }
        }
        /**
         * cette function tourne en boucle, si une clé est superieur au nombre d'images alors elle renvois les images depuis le debut
         *
         * @param WC_Product $wooCommerceProduct
         * @param int $imageNumber
         *
         * @return string
         */

        private function getDatasPictureForPostDemande($wooCommerceProduct, $imageNumber)
        {
            $imagesIds = $wooCommerceProduct->get_gallery_image_ids();
            array_unshift($imagesIds, intval($wooCommerceProduct->get_image_id()));
            $imagesPaths = array_map(
                function ($id) {
                    get_attached_file($id);//2 fois sinon ca bug..
                    return get_attached_file($id);
                },
                $imagesIds
            );
            $nombreItems = (count($imagesPaths));
            $imageNumber = $imageNumber - 1;
            $key = $imageNumber % $nombreItems;

            return $imagesPaths[$key];
        }
    }
