<?php

/**
 * Plugin Name: DigitalSignage4
 * Plugin URI: https://www.digitalsignage4.com/
 * Version: 1.0
 * Description: Sell more of your products with quality videos created automatically from all the elements of your product sheets. Create in one click videos adapted to events: Sales, promotions, Valentine's Day, Christmas, Black Friday, ...
 * Author: Acacia Dynamic
 * Author URI: https://www.acacia-dynamic.com/
 * Text Domain: digitalsignage4
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 **/

session_start();

ini_set( 'display_errors', 1 );
ini_set( 'display_startup_errors', 1 );
//error_reporting( E_ALL );

require_once __DIR__ ."/Classes/FrontShortcodeVideoDisplayer.php";
require_once __DIR__ ."/Classes/Wp_caller.php";
require_once __DIR__ ."/controllers/hook/AutomatisationHookControllerCreation.php";
require_once __DIR__ ."/controllers/override/wooCommerceProductOverride.php";
require_once __DIR__ ."/controllers/ParametreController.php";
require_once __DIR__ ."/controllers/PlaylistsController.php";
require_once __DIR__ ."/controllers/PresentationController.php";
require_once __DIR__ ."/controllers/VideoController.php";
require_once __DIR__ ."/controllers/GabaritController.php";
require_once __DIR__ ."/Kernel/API/Manager/DigitalSignageException.php";
require_once __DIR__ ."/Kernel/API/Manager/ForfaitManager.php";
require_once __DIR__ ."/Kernel/Translations/DigitalSignageTranslate.php";


if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit;
}




// Point d'entrée du module
new digitalsignage4();

// Class d'entrée du module, inclusion des hooks
class digitalsignage4
{
    private static $userAliveAlreadyChecked = false;

    
	 
	 
	
	/**
     * digitalsignage constructor.
     */
    public function __construct()
    {
        DigitalSignageTranslate::setLang(substr(get_bloginfo('language'), 0, 2));

        //permet de traduire la description du module qui est en commentaire
        load_plugin_textdomain(
            'digitalsignage',
            false,
            'digitalsignage/lang/'
        );
		
		
		$all_active_plugins = get_option('active_plugins');
		if (is_multisite()) {
			$all_active_plugins = array_merge($all_active_plugins, wp_get_active_network_plugins());
		}

		$all_active_plugins = apply_filters('active_plugins', $all_active_plugins);
		if (! stripos(implode($all_active_plugins), '/woocommerce.php')) {
			//deactivate_plugins(plugin_basename(__FILE__)); // Deactivate ourself.

			
			$message = esc_html('Désolé ! Pour utiliser Digitalsignage vous devez installer et activer le plugin WooCommerce.');
			wp_die($message, esc_html('Digitalsignage for WooCommerce'), array('back_link' => true));
		}


        FrontShortcodeVideoDisplayer::init();

        // tabs
        add_action('admin_menu', array( $this, 'add_digitalsignage_tabs' )); // Ajout du hooks des tabs du module

        // styles and scripts
        add_action('admin_init', array( $this, 'setModuleBackofficeStyle' ));
        add_action('admin_init', array( $this, 'setModuleBackOfficeScripts' ));

        // custom vidéo database
        add_action('admin_init', array( $this, 'installCustomDbVideo' ));

        // clear le buffer
        add_action('init', array( $this, 'init' ));

        // meta box dans les pages d'articles
        add_action('add_meta_boxes', array( $this, 'digital_signage_metabox' ));
		
		// Ajouter un lien de réglages dans la liste des plugins
		add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this,'digital_signage_settings_link'));
		
		// Ajouter le texte "Nécessite WooCommerce" dans la liste des plugins
        add_filter('plugin_row_meta', array($this, 'add_woocommerce_requirement_message'), 10, 2);




        // event sur le changement d'etat d'un article
        add_action('transition_post_status', array(
            new AutomatisationHookControllerCreation(),
            'handleProductChangeStatus'
        ), 9999, 3);

        $this->user_connection_alive();
    }
	
	// Ajouter le texte "Nécessite WooCommerce"
    public function add_woocommerce_requirement_message($plugin_meta, $plugin_file) {
        if ($plugin_file === plugin_basename(__FILE__)) {
            // Ajouter le texte si WooCommerce n'est pas activé
            //if (!is_plugin_active('woocommerce/woocommerce.php')) {
                $plugin_meta[] = '<span style="color: red;">Nécessite WooCommerce</span>';
            //}
        }
        return $plugin_meta;
    }
	
	
	public function digital_signage_settings_link($links) {
		$settings_link = '<a href="admin.php?page=DigitalSignageSettings">Réglages</a>';
		array_push($links, $settings_link);
		return $links;
	}

	
	
	

    public function setModuleBackofficeStyle()
    {
        wp_enqueue_style('bootstrapcss', 'https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css', array(), false, 'all');
        wp_enqueue_style('bootstrapcss');
        wp_register_style('digitalsignage_css', plugins_url('/Kernel/Views/css/styles.css', __FILE__));
        wp_enqueue_style('digitalsignage_css');
    }

    public function setModuleBackOfficeScripts()
    {
        wp_register_script('bootstrapjs', 'https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js', array( 'jquery' ), false, true);
        wp_enqueue_script('bootstrapjs');
        wp_register_script('digitalsignage_script', plugins_url('/Kernel/Views/js/script.js', __FILE__), array(), false, true);
        wp_enqueue_script('digitalsignage_script');
    }


    // Ajout des tabs du module au menu admin
    public function add_digitalsignage_tabs()
    {
        $tabs = array(
            array(
                'name'       => DigitalSignageTranslate::getTraduction("Digital_Signage_4"),
                'slug'       => 'DigitalSignageHome',
                'capability' => "manage_options",
                'callback'   => '',
                'icon'       => 'dashicons-format-video',
                'position'   => 6
            ),
            array(
                'parent_slug' => 'DigitalSignageHome',
                'name'        => DigitalSignageTranslate::getTraduction("Accueil"),
                'slug'        => 'DigitalSignageHome',
                'capability'  => "manage_options",
                'callback'    => array( new PresentationController(), "generatePage" ),
                'position'    => null
            ),
            array(
                'parent_slug' => 'DigitalSignageHome',
                'name'        => DigitalSignageTranslate::getTraduction("Videos"),
                'slug'        => 'DigitalSignageVideos',
                'capability'  => "manage_options",
                'callback'    => array( new VideoController(), "generatePage" ),
                'position'    => null
            ),
            array(
                'parent_slug' => 'DigitalSignageHome',
                'name'        => DigitalSignageTranslate::getTraduction("Playlists"),
                'slug'        => 'DigitalSignagePlaylists',
                'capability'  => "manage_options",
                'callback'    => array( new PlaylistsController(), "generatePage" ),
                'position'    => null
            ),
            array(
                'parent_slug' => 'DigitalSignageHome',
                'name'        => "Modèles",
                'slug'        => 'DigitalSignagePersoGabarit',
                'capability'  => "manage_options",
                'callback'    => array( new GabaritController(), "generatePage" ),
                'position'    => null
            ),
            array(
                'parent_slug' => 'DigitalSignageHome',
                'name'        => DigitalSignageTranslate::getTraduction("Reglages"),
                'slug'        => 'DigitalSignageSettings',
                'capability'  => "manage_options",
                'callback'    => array( new ParametreController(), "generatePage" ),
                'position'    => null
            ),
        );


        foreach ($tabs as $tab) {
            if (isset($tab['parent_slug'])) {
                add_submenu_page($tab['parent_slug'], $tab['name'], $tab['name'], $tab['capability'], $tab['slug'], $tab['callback'], $tab['position']);
            } else {
                add_menu_page($tab['name'], $tab['name'], $tab['capability'], $tab['slug'], $tab['callback'], $tab['icon'], $tab['position']);
            }
        }
    }

    // Permet la redirection via php en bloquant les affichage d'html avant la redirection
    public function init()
    {
        wp_register_script('digitalsignage_script_front', plugins_url('/Kernel/Views/js/digitalsignage.js', __FILE__), array(), false, true);
        wp_enqueue_script('digitalsignage_script_front');
        ob_start();
    }

    public function installCustomDbVideo()
    {
        if (! Wp_caller::getInstance()->create_video_table()) {
            $_SESSION['Errors'][] = DigitalSignageTranslate::getTraduction("Creation_bdd_impossible");
        }
    }

    public function digital_signage_metabox()
    {
        $screen = 'product';
        if (wc_get_product()) {
            add_meta_box(
                'digital_signage',                 // Unique ID
                DigitalSignageTranslate::getTraduction("Digital_Signage_4_creation"),      // Box title
                array( $this, 'wporg_custom_box_html' ),  // Content callback, must be of type callable
                $screen                            // Post type
            );
        }
    }

    public function wporg_custom_box_html()
    {
        $controller = new wooCommerceProductOverride();
        $controller->setArticle(wc_get_product());
        $controller->generatePage();
    }

    
    private function user_connection_alive()
    {
        $forfait = Wp_caller::getInstance()->get_data(Wp_caller::FORFAIT);

        if ($forfait) {
            ForfaitManager::instance()->setForfait($forfait);
        } elseif (! self::$userAliveAlreadyChecked) { // Si aucun forfait n'existe alors on créer un compte de test pour l'utilisateur

            try {
                $forfait = ForfaitManager::instance()->createForfaitTrial();

                if (!$forfait) {
                    foreach (ForfaitManager::instance()->getUserMessages() as $error) {
                        $_SESSION['Errors'][] = $error;
                    }
                }

                //Paramétrage par défaut
                $datas = array();
                $datas['placement_6'] = true;
                Wp_caller::getInstance()->save_data(Wp_caller::PLACEMENT, $datas);

                Wp_caller::getInstance()->save_data(Wp_caller::FORFAIT, $forfait);
            } catch (DigitalSignageException $e) {
                $e->echoError();
            }
            self::$userAliveAlreadyChecked = true;
        }
    }
}
